@@ -23,7 +23,8 @@ NULL
 #' @title urlExists
 #' @description A utility function to run a tryCatch on a URL.
 #' @param target url
-#' @export
+#' @importFrom utils capture.output
+#' @export urlExists
 urlExists <- function(target) {  
     tryCatch({  
         con <- url(target)  
@@ -33,8 +34,10 @@ urlExists <- function(target) {
     },  
     error = function(err) {  
         occur <- grep("cannot open the connection", capture.output(err));  
-        if(length(occur) > 0) FALSE;  
-    }  
-    )  
+        if(length(occur) > 0) {
+            close(con)
+            FALSE;
+        }  
+    })  
 }  
 
